
Installation
++++++++++++

To start using ``helperfns`` in your project you run the following command:

.. code-block:: shell

    pip install helperfns


.. note:: Or if you want to install it in notebooks such as jupyter notebooks you can run the code cell with the following code:

.. code-block:: shell

    !pip install helperfns


Once you install ``helperfns`` now you are ready to use it in your projects.